<?php

namespace ModinaCore\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Background;
use WP_Query;

// Exit if accessed directly
if (!defined('ABSPATH')) {
    exit;
}


class Modina_recent_posts extends Widget_Base
{

    public function get_name()
    {
        return 'modina_recent_posts';
    }

    public function get_title()
    {
        return esc_html__('Recent Post List', 'modina-core');
    }

    public function get_icon()
    {
        return 'eicon-post-list';
    }

    public function get_keywords()
    {
        return ['recent', 'post', 'article', 'news', 'latest', 'consulter'];
    }

    public function get_categories() {
        return [ 'modina-elements' ];
    }

    protected function register_controls() {


        $this->start_controls_section(
            'post_content_option',
            [
                'label' => __('Post Options', 'modina-core'),
            ]
        );

        $this->add_control(
            'post_limit',
            [
                'label' => __('How many posts want to show?', 'modina-core'),
                'type' => Controls_Manager::NUMBER,
                'default' => 2,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'title_length',
            [
                'label' => esc_html__('Title Length - Words', 'modina-core'),
                'type' => Controls_Manager::NUMBER,
                'step' => 1,
                'default' => 8,
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'show_date_icon',
            [
                'label' => esc_html__('Show Date Icon?', 'modina-core'),
                'type' => Controls_Manager::SWITCHER,
                'return_value' => 'yes',
                'default' => 'yes',
            ]
        );

        $this->add_control(
            'show_read_more_btn',
            [
                'label' => esc_html__('Show Read More Button?', 'modina-core'),
                'type' => Controls_Manager::SWITCHER,
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );

        $this->add_control(
            'read_more_txt',
            [
                'label' => esc_html__('Button Text', 'modina-core'),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Read More', 'modina-core'),
                'placeholder' => esc_html__('Read More', 'modina-core'),
                'condition' => [
                    'show_read_more_btn' => 'yes',
                ]
            ]
        );

        $this->end_controls_section();
   
        //--------------- Latest Post Style Section ---------

        $this->start_controls_section(
            'style_tab_latest_post',
            [
                'label' => esc_html__('Recent Posts', 'modina-core'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        // Title Color
        $this->add_control(
            'latest_post_title_color',
            [
                'label' => esc_html__('Title Color', 'modina-core'),
                'type' => Controls_Manager::COLOR,
                'separator' => 'before',
                'selectors' => [
                    '{{WRAPPER}} .single-post-item h5, {{WRAPPER}} .single-news-card h5, {{WRAPPER}} .single-blog-item h3' => 'color: {{VALUE}};',
                ],
            ]
        );

        // Title Typography
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'latest_post_title_typo',
                'selector' => '{{WRAPPER}} .single-post-item h5, {{WRAPPER}} .single-news-card h5, {{WRAPPER}} .single-blog-item h4',
            ]
        );

        // Button Color
        $this->add_control(
            'latest_post_icon_color',
            [
                'label' => esc_html__('Date Icon Color', 'modina-core'),
                'type' => Controls_Manager::COLOR,
                'separator' => 'before',
                'selectors' => [
                    '{{WRAPPER}} .single-post-item .post-content .post-date i' => 'color: {{VALUE}} !important;',
                ],
            ]
        );

        // Button Color
        $this->add_control(
            'latest_post_button_color',
            [
                'label' => esc_html__('Button Color', 'modina-core'),
                'type' => Controls_Manager::COLOR,
                'separator' => 'before',
                'selectors' => [
                    '{{WRAPPER}} .single-post-item .read-btn' => 'color: {{VALUE}};',
                ],
            ]
        );

        // Button Hover Color
        $this->add_control(
            'latest_post_button_h_color',
            [
                'label' => esc_html__('Button Hover Color', 'modina-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .single-post-item .read-btn:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'latest_post_img_border_radius',
            [
                'label' => esc_html__('Image Border Radius', 'modina-core'),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range'      => [
                    'px' => [
                        'min' => 1,
                        'max' => 100,
                    ],
                ],
                'selectors'  => [
                    '{{WRAPPER}} .single-post-item .thumb' => 'border-radius: {{SIZE}}{{UNIT}} !important;',
                ],
            ]
        );

        // border Color
        $this->add_control(
            'latest_post_border_bottom_color',
            [
                'label' => esc_html__('Post Border Bottom Color', 'modina-core'),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .popular-posts .single-post-item, .popular_posts .single-post-item' => 'border-color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

    }

    protected function render() {

    $settings = $this->get_settings();
    ?>
    
    <div class="popular-posts">
        <?php
            global $post;
            $args = array(
                'post_type'             => 'post',
                'post_status'           => 'publish',
                'ignore_sticky_posts'   => 1,
                'posts_per_page'        => !empty($settings['post_limit']) ? $settings['post_limit'] : 3,
            );
            $the_query = new \WP_Query($args);

            while ($the_query->have_posts()) : $the_query->the_post();
            $featured_img_url = get_the_post_thumbnail_url($post->ID,'thumbnail');
        ?>
            <div class="single-post-item">
                <?php if ( has_post_thumbnail() ) : ?>
                <div class="thumb bg-cover" style="background-image: url('<?php echo esc_url($featured_img_url); ?>')"></div>
                <?php endif; ?>
                <div class="post-content">
                    <h5><a href="<?php the_permalink(); ?>"><?php echo wp_trim_words(get_the_title(), $settings['title_length'], '') ?></a></h5>
                    
                    <?php if( 'yes' == $settings['show_date_icon']) : ?>
                    <div class="post-date"><i class="far fa-clock"></i> <?php the_time('j F, Y'); ?></div>
                    <?php endif; ?>

                    <?php if( 'yes' == $settings['show_read_more_btn']) : ?>
                    <a href="<?php the_permalink(); ?>" class="read-more-btn mt-15"><?php echo esc_html( $settings['read_more_txt'] ); ?> <i class="far fa-long-arrow-right"></i></a>
                    <?php endif; ?>
                </div>
            </div>
        <?php endwhile; ?>
        <?php wp_reset_postdata(); ?>       
    </div>

<?php
    }
}
